@@ -1,9 +1,9 @@
 # Distributions  -> Plot Distributions menu dialogs
 
-# last modified 25 June 04 by J. Fox
+# last modified 1 July 05 by J. Fox
 
 normalDistributionPlot <- function(){
-    initializeDialog(title="Normal Distribution")
+    initializeDialog(title=gettextRcmdr("Normal Distribution"))
     muVar <- tclVar("0")
     muEntry <- tkentry(top, width="6", textvariable=muVar)
     sigmaVar <- tclVar("1")
@@ -12,14 +12,13 @@ normalDistributionPlot <- function(){
     densityButton <- tkradiobutton(top, variable=functionVar, value="Density")
     distributionButton <- tkradiobutton(top, variable=functionVar, value="Cumulative Probability")
     onOK <- function(){
+        closeDialog()
         mu <- as.numeric(tclvalue(muVar))
         sigma <- as.numeric(tclvalue(sigmaVar))
         fun <- tclvalue(functionVar)
         fn <- if (fun == "Density") "dnorm" else "pnorm"
         min <- round(qnorm(.0005, mean=mu, sd=sigma), 3)
         max <- round(qnorm(.9995, mean=mu, sd=sigma), 3)
-        if (.grab.focus) tkgrab.release(top)
-        tkdestroy(top)
         command <- paste("seq(", min, ", ", max, ", length=100)", sep="")
         logger(paste(".x <- ", command, sep=""))
         assign(".x", justDoIt(command), envir=.GlobalEnv)
@@ -30,13 +29,13 @@ normalDistributionPlot <- function(){
         doItAndPrint('abline(h=0, col="gray")')
         remove(.x, envir=.GlobalEnv)
         logger("remove(.x)")
-        tkfocus(.commander)
+        tkfocus(CommanderWindow())
         }
     OKCancelHelp(helpSubject="dnorm")
-    tkgrid(tklabel(top, text="mu (mean)"), muEntry, sticky="e")
-    tkgrid(tklabel(top, text="sigma (standard deviation)"), sigmaEntry, sticky="e")
-    tkgrid(tklabel(top, text="Plot density function"), densityButton, sticky="e")
-    tkgrid(tklabel(top, text="Plot distribution function"), distributionButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("mu (mean)")), muEntry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("sigma (standard deviation)")), sigmaEntry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot density function")), densityButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot distribution function")), distributionButton, sticky="e")
     tkgrid(buttonsFrame, columnspan=2, sticky="w")
     tkgrid.configure(muEntry, sticky="w")
     tkgrid.configure(sigmaEntry, sticky="w")
@@ -46,24 +45,23 @@ normalDistributionPlot <- function(){
     }
 
 tDistributionPlot <- function(){
-    initializeDialog(title="t Distribution")
+    initializeDialog(title=gettextRcmdr("t Distribution"))
     dfVar <- tclVar("")
     dfEntry <- tkentry(top, width="6", textvariable=dfVar)
     functionVar <- tclVar("Density")
     densityButton <- tkradiobutton(top, variable=functionVar, value="Density")
     distributionButton <- tkradiobutton(top, variable=functionVar, value="Cumulative Probability")
     onOK <- function(){
+        closeDialog()
         df <- as.numeric(tclvalue(dfVar))
         if (is.na(df)) {
-            errorCondition(recall=tDistributionPlot, message="Degrees of freedom not specified.")
+            errorCondition(recall=tDistributionPlot, message=gettextRcmdr("Degrees of freedom not specified."))
             return()
             }
         fun <- tclvalue(functionVar)
         fn <- if (fun == "Density") "dt" else "pt"
         min <- round(qt(.0005, df=df), 3)
         max <- round(qt(.9995, df=df), 3)
-        if (.grab.focus) tkgrab.release(top)
-        tkdestroy(top)
         command <- paste("seq(", min, ", ", max, ", length=100)", sep="")
         logger(paste(".x <- ", command, sep=""))
         assign(".x", justDoIt(command), envir=.GlobalEnv)
@@ -73,12 +71,12 @@ tDistributionPlot <- function(){
         doItAndPrint('abline(h=0, col="gray")')
         remove(.x, envir=.GlobalEnv)
         logger("remove(.x)")
-        tkfocus(.commander)
+        tkfocus(CommanderWindow())
         }
     OKCancelHelp(helpSubject="dt")
-    tkgrid(tklabel(top, text="Degrees of freedom"), dfEntry, sticky="e")
-    tkgrid(tklabel(top, text="Plot density function"), densityButton, sticky="e")
-    tkgrid(tklabel(top, text="Plot distribution function"), distributionButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Degrees of freedom")), dfEntry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot density function")), densityButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot distribution function")), distributionButton, sticky="e")
     tkgrid(buttonsFrame, columnspan=2, sticky="w")
     tkgrid.configure(dfEntry, sticky="w")
     tkgrid.configure(densityButton, sticky="w")
@@ -87,24 +85,23 @@ tDistributionPlot <- function(){
     }
 
 chisquareDistributionPlot <- function(){
-    initializeDialog(title="Chi-squared Distribution")
+    initializeDialog(title=gettextRcmdr("Chi-squared Distribution"))
     dfVar <- tclVar("")
     dfEntry <- tkentry(top, width="6", textvariable=dfVar)
     functionVar <- tclVar("Density")
     densityButton <- tkradiobutton(top, variable=functionVar, value="Density")
     distributionButton <- tkradiobutton(top, variable=functionVar, value="Cumulative Probability")
     onOK <- function(){
+        closeDialog()
         df <- as.numeric(tclvalue(dfVar))
         if (is.na(df)) {
-            errorCondition(recall=chisquareDistributionPlot,message="Degrees of freedom not specified.")
+            errorCondition(recall=chisquareDistributionPlot,message=gettextRcmdr("Degrees of freedom not specified."))
             return()
             }
         fun <- tclvalue(functionVar)
         fn <- if (fun == "Density") "dchisq" else "pchisq"
         min <- round(qchisq(.0005, df=df), 3)
         max <- round(qchisq(.9995, df=df), 3)
-        if (.grab.focus) tkgrab.release(top)
-        tkdestroy(top)
         command <- paste("seq(", min, ", ", max, ", length=100)", sep="")
         logger(paste(".x <- ", command, sep=""))
         assign(".x", justDoIt(command), envir=.GlobalEnv)
@@ -114,12 +111,12 @@ chisquareDistributionPlot <- function(){
         doItAndPrint('abline(h=0, col="gray")')
         remove(.x, envir=.GlobalEnv)
         logger("remove(.x)")
-        tkfocus(.commander)
+        tkfocus(CommanderWindow())
         }
     OKCancelHelp(helpSubject="dchisq")
-    tkgrid(tklabel(top, text="Degrees of freedom"), dfEntry, sticky="e")
-    tkgrid(tklabel(top, text="Plot density function"), densityButton, sticky="e")
-    tkgrid(tklabel(top, text="Plot distribution function"), distributionButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Degrees of freedom")), dfEntry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot density function")), densityButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot distribution function")), distributionButton, sticky="e")
     tkgrid(buttonsFrame, columnspan=2, sticky="w")
     tkgrid.configure(dfEntry, sticky="w")
     tkgrid.configure(densityButton, sticky="w")
@@ -128,7 +125,7 @@ chisquareDistributionPlot <- function(){
     }
 
 FDistributionPlot <- function(){
-    initializeDialog(title="F Distribution")
+    initializeDialog(title=gettextRcmdr("F Distribution"))
     df1Var <- tclVar("")
     df2Var <- tclVar("")
     df1Entry <- tkentry(top, width="6", textvariable=df1Var)
@@ -137,22 +134,21 @@ FDistributionPlot <- function(){
     densityButton <- tkradiobutton(top, variable=functionVar, value="Density")
     distributionButton <- tkradiobutton(top, variable=functionVar, value="Cumulative Probability")
     onOK <- function(){
+        closeDialog()
         df1 <- as.numeric(tclvalue(df1Var))
         df2 <- as.numeric(tclvalue(df2Var))
         if (is.na(df1)) {
-            errorCondition(recall=FDistributionPlot, message="Numerator degrees of freedom not specified.")
+            errorCondition(recall=FDistributionPlot, message=gettextRcmdr("Numerator degrees of freedom not specified."))
             return()
             }
         if (is.na(df2)) {
-             errorCondition(recall=FDistributionPlot, message="Denominator degrees of freedom not specified.")
+             errorCondition(recall=FDistributionPlot, message=gettextRcmdr("Denominator degrees of freedom not specified."))
             return()
             }
         fun <- tclvalue(functionVar)
         fn <- if (fun == "Density") "df" else "pf"
         min <- round(qf(.0005, df1=df1, df2=df2), 3)
         max <- round(qf(.9995, df1=df1, df2=df2), 3)
-        if (.grab.focus) tkgrab.release(top)
-        tkdestroy(top)
         command <- paste("seq(", min, ", ", max, ", length=100)", sep="")
         logger(paste(".x <- ", command, sep=""))
         assign(".x", justDoIt(command), envir=.GlobalEnv)
@@ -163,13 +159,13 @@ FDistributionPlot <- function(){
         doItAndPrint('abline(h=0, col="gray")')
         remove(.x, envir=.GlobalEnv)
         logger("remove(.x)")
-        tkfocus(.commander)
+        tkfocus(CommanderWindow())
         }
     OKCancelHelp(helpSubject="df")
-    tkgrid(tklabel(top, text="Numerator degrees of freedom"), df1Entry, sticky="e")
-    tkgrid(tklabel(top, text="Denominator degrees of freedom"), df2Entry, sticky="e")
-    tkgrid(tklabel(top, text="Plot density function"), densityButton, sticky="e")
-    tkgrid(tklabel(top, text="Plot distribution function"), distributionButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Numerator degrees of freedom")), df1Entry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Denominator degrees of freedom")), df2Entry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot density function")), densityButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot distribution function")), distributionButton, sticky="e")
     tkgrid(buttonsFrame, columnspan=2, sticky="w")
     tkgrid.configure(df1Entry, sticky="w")
     tkgrid.configure(df2Entry, sticky="w")
@@ -179,7 +175,7 @@ FDistributionPlot <- function(){
     }
 
 binomialDistributionPlot <- function(){
-    initializeDialog(title="Binomial Distribution")
+    initializeDialog(title=gettextRcmdr("Binomial Distribution"))
     trialsVar <- tclVar("")
     trialsEntry <- tkentry(top, width="6", textvariable=trialsVar)
     probVar <- tclVar(".5")
@@ -188,21 +184,20 @@ binomialDistributionPlot <- function(){
     densityButton <- tkradiobutton(top, variable=functionVar, value="Probability")
     distributionButton <- tkradiobutton(top, variable=functionVar, value="Cumulative Probability")
     onOK <- function(){
+        closeDialog()
         trials <- as.numeric(tclvalue(trialsVar))
         if (is.na(trials)) {
-            errorCondition(recall=binomialDistributionPlot, message="Binomial trials not specified.")
+            errorCondition(recall=binomialDistributionPlot, message=gettextRcmdr("Binomial trials not specified."))
             return()
             }
         prob <- as.numeric(tclvalue(probVar))
         if (is.na(prob)) {
-            errorCondition(recall=binomialDistributionPlot, message="Probability of success not specified.")
+            errorCondition(recall=binomialDistributionPlot, message=gettextRcmdr("Probability of success not specified."))
             return()
             }
         fun <- tclvalue(functionVar)
         min <- qbinom(.0005, size=trials, prob=prob)
         max <- qbinom(.9995, size=trials, prob=prob)
-        if (.grab.focus) tkgrab.release(top)
-        tkdestroy(top)
         command <- paste(min, ":", max, sep="")
         logger(paste(".x <- ", command, sep=""))
         assign(".x", justDoIt(command), envir=.GlobalEnv)
@@ -224,13 +219,13 @@ binomialDistributionPlot <- function(){
         doItAndPrint('abline(h=0, col="gray")')
         remove(.x, envir=.GlobalEnv)
         logger("remove(.x)")
-        tkfocus(.commander)
+        tkfocus(CommanderWindow())
         }
     OKCancelHelp(helpSubject="dbinom")
-    tkgrid(tklabel(top, text="Binomial trials"), trialsEntry, sticky="e")
-    tkgrid(tklabel(top, text="Probability of success"), probEntry, sticky="e")
-    tkgrid(tklabel(top, text="Plot probability mass function"), densityButton, sticky="e")
-    tkgrid(tklabel(top, text="Plot distribution function"), distributionButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Binomial trials")), trialsEntry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Probability of success")), probEntry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot probability mass function")), densityButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot distribution function")), distributionButton, sticky="e")
     tkgrid(buttonsFrame, columnspan=2, sticky="w")
     tkgrid.configure(trialsEntry, sticky="w")
     tkgrid.configure(probEntry, sticky="w")
@@ -240,23 +235,22 @@ binomialDistributionPlot <- function(){
     }
 
 PoissonDistributionPlot <- function(){
-    initializeDialog(title="Poisson Distribution")
+    initializeDialog(title=gettextRcmdr("Poisson Distribution"))
     meanVar <- tclVar("")
     meanEntry <- tkentry(top, width="6", textvariable=meanVar)
     functionVar <- tclVar("Probability")
     densityButton <- tkradiobutton(top, variable=functionVar, value="Probability")
     distributionButton <- tkradiobutton(top, variable=functionVar, value="Cumulative Probability")
     onOK <- function(){
+        closeDialog()
         mean <- as.numeric(tclvalue(meanVar))
         if (is.na(mean)) {
-            errorCondition(recall=PoissonDistributionPlot, message="Mean not specified.")
+            errorCondition(recall=PoissonDistributionPlot, message=gettextRcmdr("Mean not specified."))
             return()
             }
         fun <- tclvalue(functionVar)
         min <- qpois(.0005, lambda=mean)
         max <- qpois(.9995, lambda=mean)
-        if (.grab.focus) tkgrab.release(top)
-        tkdestroy(top)
         command <- paste(min, ":", max, sep="")
         logger(paste(".x <- ", command, sep=""))
         assign(".x", justDoIt(command), envir=.GlobalEnv)
@@ -278,12 +272,12 @@ PoissonDistributionPlot <- function(){
         doItAndPrint('abline(h=0, col="gray")')
         remove(.x, envir=.GlobalEnv)
         logger("remove(.x)")
-        tkfocus(.commander)
+        tkfocus(CommanderWindow())
         }
     OKCancelHelp(helpSubject="dpois")
-    tkgrid(tklabel(top, text="mean"), meanEntry, sticky="e")
-    tkgrid(tklabel(top, text="Plot probability mass function"), densityButton, sticky="e")
-    tkgrid(tklabel(top, text="Plot distribution function"), distributionButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("mean")), meanEntry, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot probability mass function")), densityButton, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Plot distribution function")), distributionButton, sticky="e")
     tkgrid(buttonsFrame, columnspan=2, sticky="w")
     tkgrid.configure(meanEntry, sticky="w")
     tkgrid.configure(densityButton, sticky="w")
