@@ -1,20 +1,21 @@
-# last modified 24 May 2005 by J. Fox
+# last modified 4 September 2005 by J. Fox
 
 # File menu dialogs
 
 loadLog <- function(){
-    logFile <- tclvalue(tkgetOpenFile(filetypes='{"Script Files" {".R"}} {"All Files" {"*"}}',
+    logFile <- tclvalue(tkgetOpenFile(filetypes=gettextRcmdr('{"Script Files" {".R"}} {"All Files" {"*"}}'),
         defaultextension="log"))
     if (logFile == "") return()
     fileCon <- file(logFile, "r")
     contents <- readLines(fileCon)
     close(fileCon)
+    currentLogFileName <- getRcmdr("logFileName")
     putRcmdr("logFileName", logFile)
     .log <- LogWindow()
     if (tclvalue(tkget(.log, "1.0", "end")) != "\n"){
-        response2 <- tkmessageBox(message="Save current log file?",
+        response2 <- RcmdrTkmessageBox(message=gettextRcmdr("Save current log file?"),
                 icon="question", type="yesno", default="yes")
-        if ("yes" == tclvalue(response2)) saveLog()
+        if ("yes" == tclvalue(response2)) saveLog(currentLogFileName)
         }
     tkdelete(.log, "1.0", "end")
     tkinsert(.log, "end", paste(contents, collapse="\n"))
@@ -30,11 +31,11 @@ saveLog <- function() {
     fileCon <- file(.logFileName, "w")
     cat(log, file = fileCon)
     close(fileCon)
-    Message(paste("Script saved to", .logFileName), type="note")
+    Message(paste(gettextRcmdr("Script saved to"), .logFileName), type="note")
     }
 
 saveLogAs <- function() {
-    logFile <- tclvalue(tkgetSaveFile(filetypes='{"Script Files" {".R"}} {"All Files" {"*"}}',
+    logFile <- tclvalue(tkgetSaveFile(filetypes=gettextRcmdr('{"Script Files" {".R"}} {"All Files" {"*"}}'),
         defaultextension="R", initialfile="RCommander.R"))
     if (logFile == "") return()
     log <- tclvalue(tkget(LogWindow(), "1.0", "end"))
@@ -42,7 +43,7 @@ saveLogAs <- function() {
     cat(log, file = fileCon)
     close(fileCon)
     putRcmdr("logFileName", logFile)
-     Message(paste("Script saved to", logFile), type="note")
+     Message(paste(gettextRcmdr("Script saved to"), logFile), type="note")
     }
 
 saveOutput <- function() {
@@ -55,11 +56,11 @@ saveOutput <- function() {
     fileCon <- file(.outputFileName, "w")
     cat(output, file = fileCon)
     close(fileCon)
-    Message(paste("Output saved to", .outputFileName), type="note")
+    Message(paste(gettextRcmdr("Output saved to"), .outputFileName), type="note")
     }
 
 saveOutputAs <- function() {
-    outputFile <- tclvalue(tkgetSaveFile(filetypes='{"Output Files" {".txt"}} {"All Files" {"*"}}',
+    outputFile <- tclvalue(tkgetSaveFile(filetypes=gettextRcmdr('{"Output Files" {".txt"}} {"All Files" {"*"}}'),
         defaultextension="txt", initialfile="RCommander.txt"))
     if (outputFile == "") return()
     output <- tclvalue(tkget(OutputWindow(), "1.0", "end"))
@@ -67,16 +68,16 @@ saveOutputAs <- function() {
     cat(output, file = fileCon)
     close(fileCon)
     putRcmdr("outputFileName", outputFile)
-    Message(paste("Output saved to", outputFile), type="note")
+    Message(paste(gettextRcmdr("Output saved to"), outputFile), type="note")
     }
 
 saveWorkspaceAs <- function(){
-    saveFile <- tclvalue(tkgetSaveFile(filetypes='{"All Files" {"*"}}',
+    saveFile <- tclvalue(tkgetSaveFile(filetypes=gettextRcmdr('{"All Files" {"*"}}'),
         defaultextension="", initialfile=".RData"))
     if (saveFile == "") return()
     save(list=ls(envir=.GlobalEnv), file=saveFile)
     putRcmdr("saveFileName", saveFile)
-    Message(paste("R workspace saved to", saveFile), type="note")
+    Message(paste(gettextRcmdr("R workspace saved to"), saveFile), type="note")
     }
 
 saveWorkspace <- function() {
@@ -86,26 +87,26 @@ saveWorkspace <- function() {
         return()
         }
     else save(list=ls(envir=.GlobalEnv), file=.saveFileName)
-    Message(paste("R workspace saved to", .saveFileName), type="note")
+    Message(paste(gettextRcmdr("R workspace saved to"), .saveFileName), type="note")
     }
     
 closeCommander <- function(){
-    response <- tclvalue(tkmessageBox(message="Exit?",
+    response <- tclvalue(RcmdrTkmessageBox(message=gettextRcmdr("Exit?"),
         icon="question", type="okcancel", default="cancel"))
     if (response == "cancel") return(invisible(response))
     sink(type="message")
-    if (getRcmdr("rgl")) rgl.quit()
+    if (rglLoaded()) rgl.quit()
     if (!is.null(ActiveDataSet()) && getRcmdr("attach.data.set"))
         justDoIt(logger(paste("detach(", ActiveDataSet(), ")", sep="")))
     putRcmdr(".activeDataSet", NULL)
     putRcmdr(".activeModel", NULL)
     if (getRcmdr("log.commands") && tclvalue(tkget(LogWindow(), "1.0", "end")) != "\n"){
-        response2 <- tkmessageBox(message="Save script file?",
+        response2 <- RcmdrTkmessageBox(message=gettextRcmdr("Save script file?"),
                 icon="question", type="yesno", default="yes")
         if ("yes" == tclvalue(response2)) saveLog()
         }
     if (!getRcmdr("console.output") && tclvalue(tkget(OutputWindow(), "1.0", "end")) != "\n"){
-        response3 <- tkmessageBox(message="Save output file?",
+        response3 <- RcmdrTkmessageBox(message=gettextRcmdr("Save output file?"),
                 icon="question", type="yesno", default="yes")
         if ("yes" == tclvalue(response3)) saveOutput()
         }
@@ -131,7 +132,7 @@ Options <- function(){
     setOption <- function(option, default) {
         if (is.null(current[[option]])) default else current[[option]]
         }
-    initializeDialog(title="Commander Options")
+    initializeDialog(title=gettextRcmdr("Commander Options"))
     current <- options("Rcmdr")[[1]]
     console.output <- setOption("console.output", FALSE)
     log.commands <- setOption("log.commands", TRUE)
@@ -220,39 +221,39 @@ Options <- function(){
         Commander()
         }
     OKCancelHelp(helpSubject="Commander")
-    tkgrid(tklabel(top, text="Log commands to script window"), logCommandsCheckBox, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Log commands to script window")), logCommandsCheckBox, sticky="e")
     tkgrid.configure(logCommandsCheckBox, sticky="w")
-    tkgrid(tklabel(top, text="Log-font size (points)"), logFontSizeSlider, sticky="se")
+    tkgrid(tklabel(top, text=gettextRcmdr("Log-font size (points)")), logFontSizeSlider, sticky="se")
     tkgrid.configure(logFontSizeSlider, sticky="w")
-    tkgrid(tklabel(top, text="Log width (characters)"), logWidthSlider, sticky="se")
+    tkgrid(tklabel(top, text=gettextRcmdr("Log width (characters)")), logWidthSlider, sticky="se")
     tkgrid.configure(logWidthSlider, sticky="w")
-    tkgrid(tklabel(top, text="Log height (lines)"), logHeightSlider, sticky="se")
+    tkgrid(tklabel(top, text=gettextRcmdr("Log height (lines)")), logHeightSlider, sticky="se")
     tkgrid.configure(logHeightSlider, sticky="w")
     tkgrid(tklabel(top, text=" "), sticky="w")
-    tkgrid(tklabel(top, text="Send output to R Console"), consoleOutputCheckBox, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Send output to R Console")), consoleOutputCheckBox, sticky="e")
     tkgrid.configure(consoleOutputCheckBox, sticky="w")
-    tkgrid(tklabel(top, text="Output height (lines)"), outputHeightSlider, sticky="se")
+    tkgrid(tklabel(top, text=gettextRcmdr("Output height (lines)")), outputHeightSlider, sticky="se")
     tkgrid.configure(outputHeightSlider, sticky="w")
-    tkgrid(tklabel(contrastsFrame, text="Unordered factors"), tklabel(contrastsFrame, text="   "),
-        tklabel(contrastsFrame, text="Ordered factors"), sticky="w")
+    tkgrid(tklabel(contrastsFrame, text=gettextRcmdr("Unordered factors")), tklabel(contrastsFrame, text="   "),
+        tklabel(contrastsFrame, text=gettextRcmdr("Ordered factors")), sticky="w")
     tkgrid(contrasts1Entry, tklabel(contrastsFrame, text="   "), contrasts2Entry, sticky="w")
-    tkgrid(tklabel(top, text="Contrasts"), contrastsFrame, sticky="se")
+    tkgrid(tklabel(top, text=gettextRcmdr("Contrasts")), contrastsFrame, sticky="se")
     tkgrid.configure(contrastsFrame, sticky="sw")
-    tkgrid(tklabel(top, text="Active window grabs focus"), grabFocusCheckBox, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Active window grabs focus")), grabFocusCheckBox, sticky="e")
     tkgrid.configure(grabFocusCheckBox, sticky="w")
-    tkgrid(tklabel(top, text="Double-click presses OK button"), doubleClickCheckBox, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Double-click presses OK button")), doubleClickCheckBox, sticky="e")
     tkgrid.configure(doubleClickCheckBox, sticky="w")
-    tkgrid(tklabel(top, text="Sort variable names alphabetically"), sortNamesCheckBox, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Sort variable names alphabetically")), sortNamesCheckBox, sticky="e")
     tkgrid.configure(sortNamesCheckBox, sticky="w")
-    tkgrid(tklabel(top, text="Show edit button"), showEditButtonCheckBox, sticky="e")
+    tkgrid(tklabel(top, text=gettextRcmdr("Show edit button")), showEditButtonCheckBox, sticky="e")
     tkgrid.configure(showEditButtonCheckBox, sticky="w")
-    tkconfigure(OKbutton, text="Exit and Restart\nR Commander", width=18)
+    tkconfigure(OKbutton, text=gettextRcmdr("Exit and Restart\nR Commander"), width=18)
     if (.Platform$OS.type == "windows"){
-        tkgrid(tklabel(top, text="Scale factor for Tk elements"), scaleFactorSlider, sticky="se")
+        tkgrid(tklabel(top, text=gettextRcmdr("Scale factor for Tk elements")), scaleFactorSlider, sticky="se")
         tkgrid.configure(scaleFactorSlider, sticky="w")
         }
     else {
-        tkgrid(tklabel(top, text="Default font"), defaultFontEntry, sticky="e")
+        tkgrid(tklabel(top, text=gettextRcmdr("Default font")), defaultFontEntry, sticky="e")
         tkgrid.configure(defaultFontEntry, sticky="w")
         }
     tkgrid(buttonsFrame, columnspan=2, sticky="w")
@@ -262,24 +263,24 @@ Options <- function(){
 loadPackages <- function(){
     availablePackages <- sort(setdiff(.packages(all.available = TRUE), .packages()))
     if (length(availablePackages) == 0){
-        errorCondition(message="No packages available to load.")
+        errorCondition(message=gettextRcmdr("No packages available to load."))
         return()
         }
-    initializeDialog(title="Load Packages")
-    packagesBox <- variableListBox(top, availablePackages, title="Packages (pick one or more)",
+    initializeDialog(title=gettextRcmdr("Load Packages"))
+    packagesBox <- variableListBox(top, availablePackages, title=gettextRcmdr("Packages (pick one or more)"),
         selectmode="multiple", listHeight=10)
     onOK <- function(){
         packages <- getSelection(packagesBox)
         closeDialog(top)
         if (length(packages) == 0){
-            errorCondition(recall=loadPackages, message="You must select at least one package.")
+            errorCondition(recall=loadPackages, message=gettextRcmdr("You must select at least one package."))
             return()
             }
         for (package in packages) {
             command <- paste('library("', package, '", character.only=TRUE)', sep="")
             justDoIt(command)
             }
-        Message(paste("Packages loaded:", paste(packages, collapse=", ")), type="note")
+        Message(paste(gettextRcmdr("Packages loaded:"), paste(packages, collapse=", ")), type="note")
         }
     OKCancelHelp(helpSubject="library")
     tkgrid(getFrame(packagesBox), sticky="nw")
